# mypy-boto3-route53domains

[![PyPI - mypy-boto3-route53domains](https://img.shields.io/pypi/v/mypy-boto3-route53domains.svg?color=blue)](https://pypi.org/project/mypy-boto3-route53domains)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-route53domains.svg?color=blue)](https://pypi.org/project/mypy-boto3-route53domains)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Route53Domains 1.17.36](https://boto3.amazonaws.com/v1/documentation/api/1.17.36/reference/services/route53domains.html#Route53Domains) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.4.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-route53domains](#mypy-boto3-route53domains)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `Route53Domains` service.

```bash
python -m pip install boto3-stubs[route53domains]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[route53domains]` in your environment: `python -m pip install 'boto3-stubs[route53domains]'`

Both type checking and auto-complete should work for `Route53Domains` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[route53domains]` in your environment: `python -m pip install 'boto3-stubs[route53domains]'`

Both type checking and auto-complete should work for `Route53Domains` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[route53domains]` in your environment: `python -m pip install 'boto3-stubs[route53domains]'`
- Run `mypy` as usual

Type checking should work for `Route53Domains` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[route53domains]` in your environment: `python -m pip install 'boto3-stubs[route53domains]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Route53Domains` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`Route53DomainsClient` provides annotations for `boto3.client("route53domains")`.

```python
import boto3

from mypy_boto3_route53domains import Route53DomainsClient

client: Route53DomainsClient = boto3.client("route53domains")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: Route53DomainsClient = session.client("route53domains")
```

### Paginators annotations

`mypy_boto3_route53domains.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_route53domains import Route53DomainsClient
from mypy_boto3_route53domains.paginator import (
    ListDomainsPaginator,
    ListOperationsPaginator,
    ViewBillingPaginator,
)

client: Route53DomainsClient = boto3.client("route53domains")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_domains_paginator: ListDomainsPaginator = client.get_paginator("list_domains")
list_operations_paginator: ListOperationsPaginator = client.get_paginator("list_operations")
view_billing_paginator: ViewBillingPaginator = client.get_paginator("view_billing")
```







### Typed dictionations

`mypy_boto3_route53domains.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_route53domains.type_defs import (
    BillingRecordTypeDef,
    ContactDetailTypeDef,
    DomainSuggestionTypeDef,
    DomainSummaryTypeDef,
    DomainTransferabilityTypeDef,
    ExtraParamTypeDef,
    NameserverTypeDef,
    OperationSummaryTypeDef,
    TagTypeDef,
    AcceptDomainTransferFromAnotherAwsAccountResponseTypeDef,
    CancelDomainTransferToAnotherAwsAccountResponseTypeDef,
    CheckDomainAvailabilityResponseTypeDef,
    CheckDomainTransferabilityResponseTypeDef,
    DisableDomainTransferLockResponseTypeDef,
    EnableDomainTransferLockResponseTypeDef,
    GetContactReachabilityStatusResponseTypeDef,
    GetDomainDetailResponseTypeDef,
    GetDomainSuggestionsResponseTypeDef,
    GetOperationDetailResponseTypeDef,
    ListDomainsResponseTypeDef,
    ListOperationsResponseTypeDef,
    ListTagsForDomainResponseTypeDef,
    PaginatorConfigTypeDef,
    RegisterDomainResponseTypeDef,
    RejectDomainTransferFromAnotherAwsAccountResponseTypeDef,
    RenewDomainResponseTypeDef,
    ResendContactReachabilityEmailResponseTypeDef,
    RetrieveDomainAuthCodeResponseTypeDef,
    TransferDomainResponseTypeDef,
    TransferDomainToAnotherAwsAccountResponseTypeDef,
    UpdateDomainContactPrivacyResponseTypeDef,
    UpdateDomainContactResponseTypeDef,
    UpdateDomainNameserversResponseTypeDef,
    ViewBillingResponseTypeDef,
)

def get_structure() -> BillingRecordTypeDef:
    return {
      ...
    }
```
